import React, { useState, useEffect } from 'react'
import { Form, Select, Input } from 'antd'

const DATASOURCE_TYPE_MYSQL = 'mysql'

export default function StepTwo({ loadDataForm }) {
  const [datasourceType, setDatasourceType] = useState(DATASOURCE_TYPE_MYSQL)

  useEffect(() => {
    if (loadDataForm.getFieldValue('datasource_name')) {
      setDatasourceType(loadDataForm.getFieldValue('datasource_name'))
    }
  }, [])
  return (
    <>
      <p
        style={{
          fontWeight: 600,
          borderLeft: '3px solid #1881DA',
          paddingLeft: '12px',
        }}>
        配置加载源源
      </p>
      <Form
        name="drawForm"
        form={loadDataForm}
        labelCol={{
          span: 2,
        }}
        wrapperCol={{
          span: 6,
        }}
        initialValues={{
          datasource_name: DATASOURCE_TYPE_MYSQL,
        }}>
        <Form.Item
          label="选择数据源"
          name="datasource_name"
          rules={[
            {
              required: true,
              message: '请选择数据源!',
            },
          ]}>
          <Select
            options={[
              { label: 'My SQL', value: 'mysql' },
              { label: 'hive', value: 'hive' },
            ]}
            onSelect={val => {
              setDatasourceType(val)
            }}
            allowClear
          />
        </Form.Item>
        <Form.Item
          label="选择表"
          name="datasource_form"
          rules={[
            {
              required: true,
              message: '请选择表',
            },
          ]}>
          <Select options={[]} allowClear />
        </Form.Item>
        {datasourceType === 'mysql' ? (
          <>
            <Form.Item label="preSql" name="preSql" wrapperCol={{ span: 10 }}>
              <Input.TextArea rows={5} />
            </Form.Item>
          </>
        ) : (
          <>
            <Form.Item
              label="选择路径"
              name="dataRoute"
              wrapperCol={{ span: 10 }}
              rules={[
                {
                  required: true,
                  message: '请选择路径!',
                },
              ]}>
              <Input.TextArea rows={5} />
            </Form.Item>
            <Form.Item
              label="HDFS"
              name="datasource_hdfs"
              rules={[
                {
                  required: true,
                  message: '请输入HDFS',
                },
              ]}>
              <Input placeholder="hdfs namenode节点地址" />
            </Form.Item>
            <Form.Item
              label="选择表"
              name="file_type"
              rules={[
                {
                  required: true,
                  message: '请选择文件类型',
                },
              ]}>
              <Select options={[]} allowClear placeholder="文件的类型" />
            </Form.Item>
            <Form.Item label="分隔符" name="datasource_partition">
              <Input placeholder="读取字段的分隔符" />
            </Form.Item>
          </>
        )}
      </Form>
    </>
  )
}
